==> react-native-svg-app-icon-0.1.2.tgz: package/lib/__tests__/index-test.js <==
"use strict";

var fse = _interopRequireWildcard(require("fs-extra"));

var _globPromise = _interopRequireDefault(require("glob-promise"));

var path = _interopRequireWildcard(require("path"));

var _pixelmatch = _interopRequireDefault(require("pixelmatch"));

var _sharp = _interopRequireDefault(require("sharp"));

var tmp = _interopRequireWildcard(require("tmp"));

var index = _interopRequireWildcard(require("../index"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

describe("index", () => {
  const fixturesPath = path.join(__dirname, "fixtures");
  let tmpDir;
  beforeEach(() => {
    tmpDir = tmp.dirSync({
      unsafeCleanup: true
    });
    process.chdir(tmpDir.name);
  });
  afterEach(() => {
    tmpDir.removeCallback();
  });
  it("generates files from example matching fixtures", () => testFixture("example", 0.14));
  it("generates files from white matching fixtures", () => testFixture("white", 0.06));
  it("generates files from text matching fixtures", () => testFixture("text", 0.06), 20 * 1000);
  it("determines the correct ios asset path", async () => {
    fse.ensureDir(path.join("ios", "project", "Images.xcassets"));
    const generator = index.generate({
      icon: path.join(fixturesPath, "example", "icon.svg")
    });
    const generatedFiles = [];

    for await (const file of generator) {
      generatedFiles.push(file);
    }

    expect(generatedFiles).toContain("ios/project/Images.xcassets/AppIcon.appiconset/iphone-40@3x.png");
  });

  async function testFixture(fixture, threshold) {
    const fixtureDir = path.join(fixturesPath, fixture);
    const generator = index.generate({
      icon: path.join(fixtureDir, "icon.svg"),
      resDirPath: path.join(tmpDir.name, "android", "app", "src", "main", "res"),
      iconsetDir: path.join(tmpDir.name, "ios", fixture, "Images.xcassets", "AppIcon.appiconset")
    });
    const generatedFiles = [];

    for await (const file of generator) {
      const localPath = path.relative(tmpDir.name, file);
      const fixturePath = path.join(fixtureDir, localPath);
      await expectFilesToEqual(file, fixturePath, threshold);
      generatedFiles.push(localPath);
    }

    expect(generatedFiles.sort()).toEqual((await (0, _globPromise.default)("*/**", {
      cwd: fixtureDir,
      nodir: true
    })).sort());
  }
});

async function expectFilesToEqual(expected, actual, threshold) {
  expectFileToExist(expected);
  expectFileToExist(actual);
  const extension = path.extname(expected);

  switch (extension) {
    case ".png":
      return expectImagesToEqual(expected, actual, threshold);

    case ".json":
      return expectJsonToEqual(expected, actual);

    case ".xml":
      return expectXmlToEqual(expected, actual);

    default:
      return fail(`Unsupported comparison file type ${extension}`);
  }
}

async function expectFileToExist(path) {
  if (!(await fse.pathExists(path))) {
    fail(`File did not exist: ${path}`);
  }
}

async function expectXmlToEqual(expected, actual) {
  // TODO: Compare XML structure
  expect((await fse.readFile(expected, "utf-8"))).toEqual((await fse.readFile(actual, "utf-8")));
}

async function expectJsonToEqual(expected, actual) {
  expect((await fse.readJson(expected))).toEqual((await fse.readJson(actual)));
}

async function expectImagesToEqual(expected, actual, threshold) {
  const expectedImage = (0, _sharp.default)(expected);
  const actualImage = (0, _sharp.default)(actual);
  const expectedData = await expectedImage.ensureAlpha().raw().toBuffer({
    resolveWithObject: true
  });
  const actualData = await actualImage.ensureAlpha().raw().toBuffer({
    resolveWithObject: true
  });
  expect(actualData.info).toEqual(expectedData.info);
  const totalPixelCount = expectedData.info.width * expectedData.info.height;
  const mismatchingPixelCount = (0, _pixelmatch.default)(expectedData.data, actualData.data, null, expectedData.info.width, expectedData.info.height, {
    threshold
  });
  expect(mismatchingPixelCount / totalPixelCount).toBeLessThanOrEqual(threshold);
}

==> react-native-svg-app-icon-0.2.0.tgz: package/lib/__tests__/index-test.js <==
"use strict";

var fse = _interopRequireWildcard(require("fs-extra"));

var _globPromise = _interopRequireDefault(require("glob-promise"));

var path = _interopRequireWildcard(require("path"));

var _pixelmatch = _interopRequireDefault(require("pixelmatch"));

var _sharp = _interopRequireDefault(require("sharp"));

var tmp = _interopRequireWildcard(require("tmp"));

var index = _interopRequireWildcard(require("../index"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe("index", () => {
  const fixturesPath = path.join(__dirname, "fixtures");
  let tmpDir;
  beforeEach(() => {
    tmpDir = tmp.dirSync({
      unsafeCleanup: true
    });
    process.chdir(tmpDir.name);
  });
  afterEach(() => {
    tmpDir.removeCallback();
  });
  it("generates files from example matching fixtures", () => testFixture("example", 0.14));
  it("generates files from empty matching fixtures", () => testFixture("empty", 0.06));
  it("generates files from text matching fixtures", () => testFixture("text", 0.06), 20 * 1000);
  it("determines the correct ios asset path", async () => {
    await fse.ensureDir(path.join("ios", "project", "Images.xcassets"));
    const generator = index.generate({
      icon: {
        backgroundPath: path.join(fixturesPath, "example", "icon-background.svg"),
        foregroundPath: path.join(fixturesPath, "example", "icon.svg")
      }
    });
    const generatedFiles = [];

    for await (const file of generator) {
      generatedFiles.push(file);
    }

    expect(generatedFiles).toContain("ios/project/Images.xcassets/AppIcon.appiconset/iphone-40@3x.png");
  });

  async function testFixture(fixture, threshold) {
    const fixtureDir = path.join(fixturesPath, fixture);
    const generator = index.generate({
      icon: {
        backgroundPath: (await fse.pathExists(path.join(fixtureDir, "icon-background.svg"))) ? path.join(fixtureDir, "icon-background.svg") : undefined,
        foregroundPath: path.join(fixtureDir, "icon.svg")
      },
      resDirPath: path.join(tmpDir.name, "android", "app", "src", "main", "res"),
      iconsetDir: path.join(tmpDir.name, "ios", fixture, "Images.xcassets", "AppIcon.appiconset")
    });
    const generatedFiles = [];

    for await (const file of generator) {
      const localPath = path.relative(tmpDir.name, file);
      const fixturePath = path.join(fixtureDir, localPath);
      await expectFilesToEqual(file, fixturePath, threshold);
      generatedFiles.push(localPath);
    }

    expect(generatedFiles.sort()).toEqual((await (0, _globPromise.default)("*/**", {
      cwd: fixtureDir,
      nodir: true
    })).sort());
  }
});

async function expectFilesToEqual(expected, actual, threshold) {
  await expectFileToExist(expected);
  await expectFileToExist(actual);
  const extension = path.extname(expected);

  switch (extension) {
    case ".png":
      return expectImagesToEqual(expected, actual, threshold);

    case ".json":
      return expectJsonToEqual(expected, actual);

    case ".xml":
      return expectXmlToEqual(expected, actual);

    default:
      return fail(`Unsupported comparison file type ${extension}`);
  }
}

async function expectFileToExist(path) {
  if (!(await fse.pathExists(path))) {
    fail(`File did not exist: ${path}`);
  }
}

async function expectXmlToEqual(expected, actual) {
  // TODO: Compare XML structure
  expect(await fse.readFile(expected, "utf-8")).toEqual(await fse.readFile(actual, "utf-8"));
}

async function expectJsonToEqual(expected, actual) {
  expect(await fse.readJson(expected)).toEqual(await fse.readJson(actual));
}

async function expectImagesToEqual(expected, actual, threshold) {
  const expectedImage = (0, _sharp.default)(expected);
  const actualImage = (0, _sharp.default)(actual);
  const expectedData = await expectedImage.ensureAlpha().raw().toBuffer({
    resolveWithObject: true
  });
  const actualData = await actualImage.ensureAlpha().raw().toBuffer({
    resolveWithObject: true
  });
  expect(actualData.info).toEqual(expectedData.info);
  const totalPixelCount = expectedData.info.width * expectedData.info.height;
  const mismatchingPixelCount = (0, _pixelmatch.default)(expectedData.data, actualData.data, null, expectedData.info.width, expectedData.info.height, {
    threshold
  });
  expect(mismatchingPixelCount / totalPixelCount).toBeLessThanOrEqual(threshold);
}
